@@ -4,12 +4,14 @@ from messytables.headers import headers_guess, headers_processor, headers_make_u
 from messytables.types import type_guess, types_processor
 from messytables.types import StringType, IntegerType, FloatType, \
         DecimalType, DateType, DateUtilType
+from messytables.error import ReadError
 
 from messytables.core import Cell, TableSet, RowSet, seekable_stream
 from messytables.commas import CSVTableSet, CSVRowSet
 from messytables.excel import XLSTableSet, XLSRowSet
 from messytables.excelx import XLSXTableSet, XLSXRowSet
 from messytables.zip import ZIPTableSet
+from messytables.html import HTMLTableSet, HTMLRowSet
 from messytables.any import any_tableset, AnyTableSet
 
 from messytables.jts import rowset_as_jts, headers_and_typed_as_jts
